aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorChris Maynard <Christopher.Maynard@GTECH.COM>2012-02-01 02:05:19 +0000
committerChris Maynard <Christopher.Maynard@GTECH.COM>2012-02-01 02:05:19 +0000
commit3db18f185eef4184c263b8c9a1da68f5b40d9a07 (patch)
treebda9f291f6f9c5131c5dcfbc545d4f3f7a2d4614 /epan
parentf88e871171cbf5ccdf5093ad2c97772d5a144a8b (diff)
Fix some typos.
svn path=/trunk/; revision=40787
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-http.c6
-rw-r--r--epan/dissectors/packet-icmp.c8
-rw-r--r--epan/dissectors/packet-icmpv6.c28
-rw-r--r--epan/dissectors/packet-ipv6.c6
4 files changed, 24 insertions, 24 deletions
diff --git a/epan/dissectors/packet-http.c b/epan/dissectors/packet-http.c
index 8bd466bb0f..faba3d305a 100644
--- a/epan/dissectors/packet-http.c
+++ b/epan/dissectors/packet-http.c
@@ -958,7 +958,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
* which would require subdissectors to deal intelligently
* with empty segments.
*
- * Acccording to RFC 2616, however, 1xx responses, 204 responses,
+ * According to RFC 2616, however, 1xx responses, 204 responses,
* and 304 responses MUST NOT include a message body; if no
* content length is specified for them, we don't attempt to
* dissect the body.
@@ -1745,7 +1745,7 @@ http_payload_subdissector(tvbuff_t *tvb, proto_tree *tree,
if(strings[0] != NULL && strings[1] != NULL) {
/*
- * The string was successfuly split in two
+ * The string was successfully split in two
* Create a proxy-connect subtree
*/
if(tree) {
@@ -2670,7 +2670,7 @@ proto_register_http(void)
&http_desegment_body);
prefs_register_bool_preference(http_module, "dechunk_body",
"Reassemble chunked transfer-coded bodies",
- "Whether to reassemble bodies of entities that are transfered "
+ "Whether to reassemble bodies of entities that are transferred "
"using the \"Transfer-Encoding: chunked\" method",
&http_dechunk_body);
#ifdef HAVE_LIBZ
diff --git a/epan/dissectors/packet-icmp.c b/epan/dissectors/packet-icmp.c
index 0becf135ac..61ab6e16e2 100644
--- a/epan/dissectors/packet-icmp.c
+++ b/epan/dissectors/packet-icmp.c
@@ -1061,7 +1061,7 @@ static guint32 get_best_guess_mstimeofday(tvbuff_t *tvb, gint offset, guint32 co
/* Account for the special case from RFC 792 as best we can by clearing
* the msb. Ref: [Page 16] of http://tools.ietf.org/html/rfc792:
- If the time is not available in miliseconds or cannot be provided
+ If the time is not available in milliseconds or cannot be provided
with respect to midnight UT then any time can be inserted in a
timestamp provided the high order bit of the timestamp is also set
to indicate this non-standard value.
@@ -1091,8 +1091,8 @@ static guint32 get_best_guess_mstimeofday(tvbuff_t *tvb, gint offset, guint32 co
}
/* Both are bigger than MSPERDAY, but neither one's msb's are set. This
- * is cleary invalid, but now what TODO? For now, take the one closest to
- * the commparative timestamp, which is another way of saying, "let's
+ * is clearly invalid, but now what TODO? For now, take the one closest to
+ * the comparative timestamp, which is another way of saying, "let's
* return a deterministic wild guess. */
if (abs(be_ts - comp_ts) < abs(le_ts - comp_ts))
return (be_ts);
@@ -1665,7 +1665,7 @@ proto_register_icmp(void)
{ "MTU", "icmp.int_info.mtu", FT_BOOLEAN, 8, NULL, INT_INFO_MTU,
"True: MTU present; False: MTU not present", HFILL }},
{ &hf_icmp_int_info_afi,
- { "Address Family Identfier", "icmp.int_info.afi", FT_UINT16, BASE_DEC, NULL, 0x0,
+ { "Address Family Identifier", "icmp.int_info.afi", FT_UINT16, BASE_DEC, NULL, 0x0,
"Address Family of the interface address", HFILL }},
{ &hf_icmp_int_info_ipv4,
{ "Source", "icmp.int_info.ip", FT_IPv4, BASE_NONE, NULL, 0x0,
diff --git a/epan/dissectors/packet-icmpv6.c b/epan/dissectors/packet-icmpv6.c
index 39aa03af41..d9ec6f8377 100644
--- a/epan/dissectors/packet-icmpv6.c
+++ b/epan/dissectors/packet-icmpv6.c
@@ -80,7 +80,7 @@
* RFC 5269: Distributing a Symmetric Fast Mobile IPv6 (FMIPv6) Handover Key Using SEcure Neighbor Discovery (SEND)
* RFC 5271: Mobile IPv6 Fast Handovers for 3G CDMA Networks
* RFC 6275: Mobility Support in IPv6
* draft-ieft-roll-rpl-19.txt: RPL: IPv6 Routing Protocol for Low power and Lossy Networks
* draft-ietf-csi-proxy-send-05: Secure Proxy ND Support for SEND
* draft-ietf-6lowpan-nd-18: Neighbor Discovery Optimization for Low Power and Lossy Networks (6LoWPAN)
* http://www.iana.org/assignments/icmpv6-parameters (last updated 2011-04-08)
@@ -575,7 +575,7 @@ static const value_string icmpv6_type_val[] = {
{ ICMP6_MCAST_ROUTER_SOLICIT, "Multicast Router Solicitation" }, /* [RFC4286] */
{ ICMP6_MCAST_ROUTER_TERM, "Multicast Router Termination" }, /* [RFC4286] */
{ ICMP6_FMIPV6_MESSAGES, "FMIPv6" }, /* [RFC5568] */
- { ICMP6_RPL_CONTROL, "RPL Control" }, /* draft-ieft-roll-rpl-19.txt Pending IANA */
+ { ICMP6_RPL_CONTROL, "RPL Control" }, /* draft-ietf-roll-rpl-19.txt Pending IANA */
{ ICMP6_6LOWPANND_DAR, "Duplicate Address Request"}, /* draft-ietf-6lowpan-nd-18.txt Pending IANA */
{ ICMP6_6LOWPANND_DAC, "Duplicate Address Confirmation"}, /* draft-ietf-6lowpan-nd-18.txt Pending IANA */
{ 200, "Private experimentation" }, /* [RFC4443] */
@@ -602,7 +602,7 @@ static const value_string icmpv6_unreach_code_val[] = {
{ ICMP6_DST_UNREACH_NOPORT, "Port unreachable" },
{ ICMP6_DST_UNREACH_INGR_EGR, "Source address failed ingress/egress policy" },
{ ICMP6_DST_UNREACH_REJECT, "Reject route to destination" },
- { ICMP6_DST_UNREACH_ERROR, "Error in Source Routing Header" }, /* [draft-ieft-roll-rpl-19.txt] */
+ { ICMP6_DST_UNREACH_ERROR, "Error in Source Routing Header" }, /* [draft-ietf-roll-rpl-19.txt] */
{ 0, NULL }
};
@@ -801,8 +801,8 @@ static const true_false_string tfs_ni_flag_a = {
#define ND_OPT_DNS_SEARCH_LIST 31
#define ND_OPT_PROXY_SIGNATURE 32
/* draft-6lowpan-nd types, pending IANA assignment */
-#define ND_OPT_ADDR_REGISTRATION 131 /* Conflit with RFC6106.. */
-#define ND_OPT_6LOWPAN_CONTEXT 132 /* Conflit with draft-ietf-csi-proxy-send-05.txt.. */
+#define ND_OPT_ADDR_REGISTRATION 131 /* Conflict with RFC6106.. */
+#define ND_OPT_6LOWPAN_CONTEXT 132 /* Conflict with draft-ietf-csi-proxy-send-05.txt.. */
#define ND_OPT_AUTH_BORDER_ROUTER 33
static const value_string option_vals[] = {
@@ -839,7 +839,7 @@ static const value_string option_vals[] = {
/* 32 */ { ND_OPT_PROXY_SIGNATURE, "Proxy Signature (PS)" }, /* [draft-ietf-csi-proxy-send-05.txt] */
/* 31 */ { ND_OPT_ADDR_REGISTRATION, "Address Registration Option" }, /* [draft-ietf-6lowpan-nd-18.txt] */
/* 32 */ { ND_OPT_6LOWPAN_CONTEXT, "6LoWPAN Context Option" }, /* [draft-ietf-6lowpan-nd-18.txt] */
-/* 33 */ { ND_OPT_AUTH_BORDER_ROUTER, "Authorative Border Router" }, /* [draft-ietf-6lowpan-nd-18.txt] */
+/* 33 */ { ND_OPT_AUTH_BORDER_ROUTER, "Authoritative Border Router" }, /* [draft-ietf-6lowpan-nd-18.txt] */
/* 34-137 Unassigned */
{ 138, "CARD Request" }, /* [RFC4065] */
{ 139, "CARD Reply" }, /* [RFC4065] */
@@ -1025,11 +1025,11 @@ static const value_string rpl_code_val[] = {
{ ICMP6_RPL_DIS, "DODAG Information Solicitation" },
{ ICMP6_RPL_DIO, "DODAG Information Object" },
{ ICMP6_RPL_DAO, "Destination Advertisement Object" },
- { ICMP6_RPL_DAOACK, "Destination Advertisement Object Acknowledgement" },
+ { ICMP6_RPL_DAOACK, "Destination Advertisement Object Acknowledgment" },
{ ICMP6_RPL_SDIS, "Secure DODAG Information Solicitation" },
{ ICMP6_RPL_SDIO, "Secure DODAG Information Object" },
{ ICMP6_RPL_SDAO, "Secure Destination Advertisement Object" },
- { ICMP6_RPL_SDAOACK,"Secure Destination Advertisement Object Acknowledgement" },
+ { ICMP6_RPL_SDAOACK,"Secure Destination Advertisement Object Acknowledgment" },
{ ICMP6_RPL_CC, "Consistency Check" },
{ 0, NULL }
};
@@ -1531,7 +1531,7 @@ dissect_icmpv6_nd_opt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
opt_offset += par_len;
/* Padding */
- /* TODO: Calculate padding length and exlude from the signature */
+ /* TODO: Calculate padding length and exclude from the signature */
break;
}
case ND_OPT_TIMESTAMP: /* Timestamp Option (13) */
@@ -2015,7 +2015,7 @@ dissect_icmpv6_nd_opt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_digital_signature_padding , tvb, opt_offset, par_len, ENC_NA);
opt_offset += par_len;
/* Padding */
- /* TODO: Calculate padding length and exlude from the signature */
+ /* TODO: Calculate padding length and exclude from the signature */
break;
}
case ND_OPT_ADDR_REGISTRATION: /* Address Registration (TBD1 Pending IANA...) */
@@ -2413,7 +2413,7 @@ dissect_icmpv6_rpl_opt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
}
opt_offset += 4;
- /* Preferrred Lifetime */
+ /* Preferred Lifetime */
ti_opt = proto_tree_add_item(icmp6opt_tree, hf_icmpv6_rpl_opt_prefix_plifetime, tvb, opt_offset, 4, ENC_BIG_ENDIAN);
switch(tvb_get_ntohl(tvb, opt_offset)){
case 0xffffffff:
@@ -3937,7 +3937,7 @@ proto_register_icmpv6(void)
{ "Nonce", "icmpv6.opt.nonce", FT_BYTES, BASE_NONE, NULL, 0x0,
"A field containing a random number selected by the sender of the solicitation message", HFILL }},
{ &hf_icmpv6_opt_certificate_padding,
- { "Certificat and Padding", "icmpv6.opt.certificate_padding", FT_NONE, BASE_NONE, NULL, 0x0,
+ { "Certificate and Padding", "icmpv6.opt.certificate_padding", FT_NONE, BASE_NONE, NULL, 0x0,
NULL, HFILL }},
{ &hf_icmpv6_opt_ipa_option_code,
{ "Option-code", "icmpv6.opt.ipa.option_code", FT_UINT8, BASE_DEC, VALS(nd_opt_ipa_option_code_val), 0x00,
@@ -3992,7 +3992,7 @@ proto_register_icmpv6(void)
"This value indicates the validity of the MAP's address and the RCoA.", HFILL }},
{ &hf_icmpv6_opt_map_global_address,
{ "Global Address", "icmpv6.opt.map.global_address", FT_IPv6, BASE_NONE, NULL, 0x0,
- "TOne of the MAP's global addresses", HFILL }},
+ "One of the MAP's global addresses", HFILL }},
{ &hf_icmpv6_opt_route_info_flag,
{ "Flag", "icmpv6.opt.route_info.flag", FT_UINT8, BASE_HEX, NULL, 0x00,
NULL, HFILL }},
@@ -4543,7 +4543,7 @@ proto_register_icmpv6(void)
{ "Flag", "icmpv6.rpl.cc.flag", FT_UINT8, BASE_HEX, NULL, 0x0,
NULL, HFILL }},
{ &hf_icmpv6_rpl_cc_flag_r,
- { "Reponse (R)", "icmpv6.rpl.cc.flag.r", FT_BOOLEAN, 8, NULL, RPL_CC_FLAG_R,
+ { "Response (R)", "icmpv6.rpl.cc.flag.r", FT_BOOLEAN, 8, NULL, RPL_CC_FLAG_R,
"Indicates whether the CC message is a response", HFILL }},
{ &hf_icmpv6_rpl_cc_flag_rsv,
{ "Reserved", "icmpv6.rpl.cc.flag.rsv", FT_UINT8, BASE_DEC, NULL, RPL_CC_FLAG_RESERVED,
@@ -80,7 +80,7 @@
* RFC 5271: Mobile IPv6 Fast Handovers for 3G CDMA Networks
* RFC 6275: Mobility Support in IPv6
- * draft-ieft-roll-rpl-19.txt: RPL: IPv6 Routing Protocol for Low power and Lossy Networks
+ * draft-ietf-roll-rpl-19.txt: RPL: IPv6 Routing Protocol for Low power and Lossy Networks
* draft-ietf-csi-proxy-send-05: Secure Proxy ND Support for SEND
* draft-ietf-6lowpan-nd-18: Neighbor Discovery Optimization for Low Power and Lossy Networks (6LoWPAN)
diff --git a/epan/dissectors/packet-ipv6.c b/epan/dissectors/packet-ipv6.c
index ff2be46da2..300ca1b697 100644
--- a/epan/dissectors/packet-ipv6.c
+++ b/epan/dissectors/packet-ipv6.c
@@ -551,7 +551,7 @@ enum {
IPv6_RT_HEADER_RPL=4
};
/* Routeing Header Types */
static const value_string routing_header_type[] = {
{ IPv6_RT_HEADER_SOURCE_ROUTING, "IPv6 Source Routing" },
{ IPv6_RT_HEADER_NIMROD, "Nimrod" },
@@ -1478,7 +1478,7 @@ static const value_string shimctrlvals[] = {
{ SHIM6_TYPE_R1BIS, "R1bis" },
{ SHIM6_TYPE_I2BIS, "I2bis" },
{ SHIM6_TYPE_UPD_REQ, "Update Request" },
- { SHIM6_TYPE_UPD_ACK, "Update Acknowledgement" },
+ { SHIM6_TYPE_UPD_ACK, "Update Acknowledgment" },
{ SHIM6_TYPE_KEEPALIVE, "Keepalive" },
{ SHIM6_TYPE_PROBE, "Probe" },
{ 0, NULL }
@@ -2297,7 +2297,7 @@ proto_register_ipv6(void)
{ &hf_ipv6_routing_hdr_type,
{ "Type", "ipv6.routing_hdr.type",
FT_UINT8, BASE_DEC, VALS(routing_header_type), 0x0,
- "Routeing Header Type", HFILL }},
+ "Routing Header Type", HFILL }},
{ &hf_ipv6_routing_hdr_left,
{ "Segments Left", "ipv6.routing_hdr.left",
FT_UINT8, BASE_DEC, NULL, 0x0,
@@ -551,7 +551,7 @@ enum {
IPv6_RT_HEADER_RPL=4
};
-/* Routeing Header Types */
+/* Routing Header Types */
static const value_string routing_header_type[] = {
{ IPv6_RT_HEADER_SOURCE_ROUTING, "IPv6 Source Routing" },